@@ -29,8 +29,10 @@ import webbrowser
 import subprocess
 import zipfile
 import shutil
+import requests
 import pkg_resources
 import urllib.request
+from bs4 import BeautifulSoup
 from datetime import datetime
 from shutil import copyfile
 
@@ -48,11 +50,31 @@ now = datetime.now()
 
 # Get package version
 def geeadd_version():
-    print(pkg_resources.get_distribution("geeadd").version)
+    url = "https://pypi.org/project/geeadd/"
+    source = requests.get(url)
+    html_content = source.text
+    soup = BeautifulSoup(html_content, "html.parser")
+    company = soup.find("h1")
+    if (
+        not pkg_resources.get_distribution("geeadd").version
+        == company.string.strip().split(" ")[-1]
+    ):
+        print(
+            "\n"
+            + "========================================================================="
+        )
+        print(
+            "Current version of geeadd is {} upgrade to lastest version: {}".format(
+                pkg_resources.get_distribution("geeadd").version,
+                company.string.strip().split(" ")[-1],
+            )
+        )
+        print(
+            "========================================================================="
+        )
 
 
-def version_from_parser(args):
-    geeadd_version()
+geeadd_version()
 
 
 # Go to the readMe
@@ -95,64 +117,74 @@ def cancel_tasks(tasks):
             print("Attempting to cancel all tasks")
             all_tasks = [
                 task
-                for task in ee.data.getTaskList()
-                if task["state"] == "RUNNING" or task["state"] == "READY"
+                for task in ee.data.listOperations()
+                if task["metadata"]["state"] == "RUNNING"
+                or task["metadata"]["state"] == "PENDING"
             ]
             if len(all_tasks) > 0:
                 for task in all_tasks:
-                    ee.data.cancelTask(task["id"])
+                    ee.data.cancelOperation(task["name"])
                 print(
                     "Request completed task ID or task type {} cancelled".format(tasks)
                 )
             elif len(all_tasks) == 0:
-                print("No Running or Ready tasks found")
+                print("No Running or Pending tasks found")
         except Exception as e:
             print(e)
     elif tasks == "running":
         try:
             print("Attempting to cancel running tasks")
             running_tasks = [
-                task for task in ee.data.getTaskList() if task["state"] == "RUNNING"
+                task
+                for task in ee.data.listOperations()
+                if task["metadata"]["state"] == "RUNNING"
             ]
             if len(running_tasks) > 0:
                 for task in running_tasks:
-                    ee.data.cancelTask(task["id"])
+                    ee.data.cancelOperation(task["name"])
                 print(
-                    "Request completed task ID or task type {} cancelled".format(tasks)
+                    "Request completed task ID or task type: {} cancelled".format(tasks)
                 )
             elif len(running_tasks) == 0:
                 print("No Running tasks found")
         except Exception as e:
             print(e)
-    elif tasks == "ready":
+    elif tasks == "pending":
         try:
-            print("Attempting to cancel queued tasks or ready tasks")
+            print("Attempting to cancel queued tasks or pending tasks")
             ready_tasks = [
-                task for task in ee.data.getTaskList() if task["state"] == "READY"
+                task
+                for task in ee.data.listOperations()
+                if task["metadata"]["state"] == "PENDING"
             ]
             if len(ready_tasks) > 0:
                 for task in ready_tasks:
-                    ee.data.cancelTask(task["id"])
+                    ee.data.cancelOperation(task["name"])
                 print(
-                    "Request completed task ID or task type {} cancelled".format(tasks)
+                    "Request completed task ID or task type: {} cancelled".format(tasks)
                 )
             elif len(ready_tasks) == 0:
-                print("No Ready tasks found")
+                print("No Pending tasks found")
         except Exception as e:
             print(e)
     elif tasks is not None:
         try:
             print("Attempting to cancel task with given task ID {}".format(tasks))
-            get_status = ee.data.getTaskStatus(tasks)[0]
-            if get_status["state"] == "RUNNING" or get_status["state"] == "READY":
+            get_status = ee.data.getOperation(
+                "projects/earthengine-legacy/operations/{}".format(tasks)
+            )
+            if (
+                get_status["metadata"]["state"] == "RUNNING"
+                or get_status["metadata"]["state"] == "PENDING"
+            ):
                 ee.data.cancelTask(task["id"])
                 print(
-                    "Request completed task ID or task type {} cancelled".format(tasks)
+                    "Request completed task ID or task type: {} cancelled".format(tasks)
                 )
-            elif get_status["state"] == "UNKNOWN":
-                print("No task found with given task ID {}".format(tasks))
+            else:
+                print("Task in status {}".format(get_status["metadata"]["state"]))
         except Exception as e:
-            print(e)
+            print("No task found with given task ID {}".format(tasks))
 
 
 def cancel_tasks_from_parser(args):
@@ -162,7 +194,9 @@ def cancel_tasks_from_parser(args):
 def delete(ids):
     try:
         print("Recursively deleting path: {}".format(ids))
-        subprocess.call("earthengine --no-use_cloud_api rm -r " + ids,shell=True)
+        subprocess.call(
+            "earthengine rm -r {}".format(ids), shell=True, stdout=subprocess.PIPE
+        )
     except Exception as e:
         print(e)
 
@@ -171,31 +205,50 @@ def delete_collection_from_parser(args):
     delete(ids=args.id)
 
 
-def quota():
+def quota(project):
     ee.Initialize()
-    for roots in ee.data.getAssetRoots():
-        quota = ee.data.getAssetRootQuota(roots["id"])
-        print("")
-        print(
-            "Root assets path: {}".format(
-                roots["id"].replace("projects/earthengine-legacy/assets/", "")
+    if project is not None:
+        try:
+            if not project.endswith('/'):
+                project = project+'/'
+            else:
+                project = project
+            project_detail= ee.data.getAsset(project)
+            print("")
+            if 'sizeBytes' in project_detail['quota']:
+                print('Used {} of {}'.format(humansize(int(project_detail['quota']['sizeBytes'])),(humansize(int(project_detail['quota']['maxSizeBytes'])))))
+            else:
+                print('Used 0 of {}'.format(humansize(int(project_detail['quota']['maxSizeBytes']))))
+            if 'assetCount' in project_detail['quota']:
+                print('Used {:,} assets of {:,} total'.format(int(project_detail['quota']['assetCount']),int(project_detail['quota']['maxAssetCount'])))
+            else:
+                print('Used 0 assets of {:,} total'.format(int(project_detail['quota']['maxAssetCount'])))
+        except Exception as e:
+            print(e)
+    else:
+        for roots in ee.data.getAssetRoots():
+            quota = ee.data.getAssetRootQuota(roots["id"])
+            print("")
+            print(
+                "Root assets path: {}".format(
+                    roots["id"].replace("projects/earthengine-legacy/assets/", "")
+                )
             )
-        )
-        print(
-            "Used {} of {}".format(
-                humansize(quota["asset_size"]["usage"]),
-                humansize(quota["asset_size"]["limit"]),
+            print(
+                "Used {} of {}".format(
+                    humansize(quota["asset_size"]["usage"]),
+                    humansize(quota["asset_size"]["limit"]),
+                )
             )
-        )
-        print(
-            "Used {:,} assets of {:,} total".format(
-                quota["asset_count"]["usage"], quota["asset_count"]["limit"]
+            print(
+                "Used {:,} assets of {:,} total".format(
+                    quota["asset_count"]["usage"], quota["asset_count"]["limit"]
+                )
             )
-        )
 
 
 def quota_from_parser(args):
-    quota()
+    quota(project=args.project)
 
 
 def ee_report_from_parser(args):
@@ -224,15 +277,15 @@ def app2script_from_parser(args):
 
 def tasks():
     ee.Initialize()
-    statuses = ee.data.getTaskList()
+    statuses = ee.data.listOperations()
     st = []
     for status in statuses:
-        st.append(status["state"])
+        st.append(status["metadata"]["state"])
     print("Tasks Running: " + str(st.count("RUNNING")))
-    print("Tasks Ready: " + str(st.count("READY")))
-    print("Tasks Completed: " + str(st.count("COMPLETED")))
+    print("Tasks Pending: " + str(st.count("PENDING")))
+    print("Tasks Completed: " + str(st.count("SUCCEEDED")))
     print("Tasks Failed: " + str(st.count("FAILED")))
-    print("Tasks Cancelled: " + str(st.count("CANCELLED")))
+    print("Tasks Cancelled: " + str(st.count("CANCELLED")+st.count("CANCELLING")))
 
 
 def tasks_from_parser(args):
@@ -241,7 +294,7 @@ def tasks_from_parser(args):
 
 def assetsize(asset):
     ee.Initialize()
-    header = ee.data.getInfo(asset)["type"]
+    header = ee.data.getAsset(asset)["type"]
     if header == "IMAGE_COLLECTION":
         collc = ee.ImageCollection(asset)
         size = collc.aggregate_array("system:asset_size")
@@ -265,16 +318,21 @@ def assetsize(asset):
             + str(humansize(collc.get("system:asset_size").getInfo()))
         )
     elif header == "FOLDER":
-        b = subprocess.check_output(
-            "earthengine --no-use_cloud_api du " + asset + " -s", shell=True
-        ).decode("ascii")
-        num = subprocess.check_output(
-            "earthengine --no-use_cloud_api ls " + asset, shell=True
-        ).decode("ascii")
-        size = humansize(float(b.strip().split(" ")[0]))
+        b = subprocess.Popen(
+            "earthengine du {} -s".format(asset), shell=True,stdout=subprocess.PIPE
+        )
+        out, err = b.communicate()
+        val=[item for item in out.decode("ascii").split(" ") if item.isdigit()]
+        size = humansize(float(val[0]))
+        num = subprocess.Popen("earthengine ls {}".format(asset), shell=True, stdout=subprocess.PIPE
+        )
+        out, err = num.communicate()
+        out=out.decode("ascii")
+        num = [i for i in out.split("\n") if i if len(i)>1 if not i.startswith("Running")]
         print("")
+        # print(num.split("\n"))
         print(str(asset) + " ===> " + str(size))
-        print("Total number of items in folder: {}".format(len(num.split("\n")) - 1))
+        print("Total number of items in folder: {}".format(len(num)))
 
 
 def assetsize_from_parser(args):
@@ -434,11 +492,6 @@ def main(args=None):
     )
     subparsers = parser.add_subparsers()
 
-    parser_version = subparsers.add_parser(
-        "version", help="Prints porder version and exists"
-    )
-    parser_version.set_defaults(func=version_from_parser)
-
     parser_read = subparsers.add_parser(
         "readme", help="Go the web based porder readme page"
     )
@@ -447,6 +500,12 @@ def main(args=None):
     parser_quota = subparsers.add_parser(
         "quota", help="Print Earth Engine total quota and used quota"
     )
+    optional_named = parser_quota.add_argument_group("Optional named arguments")
+    optional_named.add_argument(
+        "--project",
+        help="Project Name usually in format projects/project-name/assets/",
+        default=None,
+    )
     parser_quota.set_defaults(func=quota_from_parser)
 
     parser_app2script = subparsers.add_parser(
@@ -497,15 +556,17 @@ def main(args=None):
 
     parser_tasks = subparsers.add_parser(
         "tasks",
-        help="Queries current task status [completed,running,ready,failed,cancelled]",
+        help="Queries current task status [completed,running,pending,failed,cancelled]",
     )
     parser_tasks.set_defaults(func=tasks_from_parser)
 
-    parser_cancel = subparsers.add_parser("cancel", help="Cancel all running tasks")
+    parser_cancel = subparsers.add_parser(
+        "cancel", help="Cancel all, running or ready tasks or task ID"
+    )
     required_named = parser_cancel.add_argument_group("Required named arguments.")
     required_named.add_argument(
         "--tasks",
-        help="You can provide tasks as running or ready or all or even a single task id",
+        help="You can provide tasks as running or pending or all or even a single task id",
         required=True,
         default=None,
     )
